# Colosseum

To run the Colosseum server for testing, refer to [the server repo](https://github.com/PettingZoo-Team/Colosseum-Server).

To run one or multiple clients you can use the following command:

```
python test_tournament_clients user1 user2 ...
```
